load('figures_3_and_5_data.mat');

% plot changes in thalamo-cortical and cortico-thalamic cross-frequency
% information transfer in anesthesia, seizure, and 5-meo-dmt states
% relative to norma waking baselines

colors = {[145 73 1]./255,  [35 253 35]./255, [255 109 182]./255};
shapes = {'*', 's','+'};
names={'Human ET Patients'; 'Long-Evans Rats';...
    'GAERS Rats'; 'C57/BL6 Mice'};

thal_to_cort_titles = {'Ventral Intermediate Nucleus to Sensorimotor Cortex'; 'Ventral Posterior Nucleus to Somatosensory Cortex';...
    'Ventral Posterior Nucleus to Somatosensory Cortex'; 'Mediodorsal Nucleus to Prefrontal Cortex'};
    
cort_to_thal_titles = {'Sensorimotor Cortex to Ventral Intermediate Nucleus'; 'Somatosensory Cortex to Ventral Posterior Nucleus';...
    'Somatosensory Cortex to Ventral Posterior Nucleus'; 'Prefrontal Cortex to Mediodorsal Nucleus'};

p_strings = {'n.s.'; '*'; '**'; '***'};


all_rat_anesthesia_cort_to_thal = [rat_wake_cort_to_thal' rat_anesthesia_cort_to_thal'];
p = signrank(rat_wake_cort_to_thal, rat_anesthesia_cort_to_thal, 'Tail', 'right');
if p > 0.05
    p_string = p_strings{1};
elseif p < 0.05 && p >= 0.01
    p_string = p_strings{2};
elseif p < 0.01 && p >= 0.001
    p_string = p_strings{3};
else
    p_string = p_strings{4};
end
figure('Position', [44 0 778 505]); 
boxplot(all_rat_anesthesia_cort_to_thal, 'symbol', '');
hold on;
scatter(ones(1,9), rat_wake_cort_to_thal, 100, 'filled', 'k');
scatter(ones(1,9)+1, rat_anesthesia_cort_to_thal, 100, 'filled', 'r');
ylabel({'Cross-Frequency Corticothalamic'; 'Information Transfer'});
set(gca, 'Fontsize', 20);
for i = 1:9
    plot([1 2], [rat_wake_cort_to_thal(i) rat_anesthesia_cort_to_thal(i)], 'Color', [0, 0, 0, 0.3])
end
text(1.5, max(rat_wake_cort_to_thal), p_string, 'HorizontalAlignment', 'center', 'FontSize', 30);
title({names{2}; cort_to_thal_titles{2}});
set(gca, 'XTickLabel', {'Awake', 'Propofol'}, 'FontSize', 18);

all_human_anesthesia_cort_to_thal = [human_wake_cort_to_thal' human_anesthesia_cort_to_thal'];
p = signrank(human_wake_cort_to_thal, human_anesthesia_cort_to_thal, 'Tail', 'right');
if p > 0.05
    p_string = p_strings{1};
elseif p < 0.05 && p >= 0.01
    p_string = p_strings{2};
elseif p < 0.01 && p >= 0.001
    p_string = p_strings{3};
else
    p_string = p_strings{4};
end
figure('Position', [44 0 778 505]);  
boxplot(all_human_anesthesia_cort_to_thal, 'symbol', '');
hold on;
scatter(ones(1,10), human_wake_cort_to_thal, 100, 'filled', 'k');
scatter(ones(1,10)+1, human_anesthesia_cort_to_thal, 100, 'filled', 'r');
set(gca, 'XTickLabel', {'Awake', 'Propofol'}, 'FontSize', 15);
ylabel({'Cross-Frequency Corticothalamic'; 'Information Transfer'});
title({names{1}; cort_to_thal_titles{1}});
set(gca, 'Fontsize', 20);
for i = 1:10
    plot([1 2], [human_wake_cort_to_thal(i) human_anesthesia_cort_to_thal(i)], 'Color', [0, 0, 0, 0.3])
end
text(1.5, max(human_wake_cort_to_thal), p_string, 'HorizontalAlignment', 'center', 'FontSize', 30);

all_rat_anesthesia_thal_to_cort = [rat_wake_thal_to_cort' rat_anesthesia_thal_to_cort'];
p = signrank(rat_wake_thal_to_cort, rat_anesthesia_thal_to_cort, 'Tail', 'right');
if p > 0.05
    p_string = p_strings{1};
elseif p < 0.05 && p >= 0.01
    p_string = p_strings{2};
elseif p < 0.01 && p >= 0.001
    p_string = p_strings{3};
else
    p_string = p_strings{4};
end
figure('Position', [44 0 778 505]);  
boxplot(all_rat_anesthesia_thal_to_cort, 'symbol', '');
hold on;
scatter(ones(1,9), rat_wake_thal_to_cort, 100, 'filled', 'k');
scatter(ones(1,9)+1, rat_anesthesia_thal_to_cort, 100, 'filled', 'r');
set(gca, 'XTickLabel', {'Awake', 'Propofol'}, 'FontSize', 15);
title({names{2}; thal_to_cort_titles{2}});
ylabel({'Cross-Frequency Thalamocortical'; 'Information Transfer'});
set(gca, 'Fontsize', 20);
for i = 1:9
    plot([1 2], [rat_wake_thal_to_cort(i) rat_anesthesia_thal_to_cort(i)], 'Color', [0, 0, 0, 0.3])
end
text(1.5, max(rat_wake_thal_to_cort), p_string, 'HorizontalAlignment', 'center', 'FontSize', 30);

all_human_anesthesia_thal_to_cort = [human_wake_thal_to_cort' human_anesthesia_thal_to_cort'];
p = signrank(human_wake_thal_to_cort, human_anesthesia_thal_to_cort, 'Tail', 'right');
if p > 0.05
    p_string = p_strings{1};
elseif p < 0.05 && p >= 0.01
    p_string = p_strings{2};
elseif p < 0.01 && p >= 0.001
    p_string = p_strings{3};
else
    p_string = p_strings{4};
end
figure('Position', [44 0 778 505]);  
boxplot(all_human_anesthesia_thal_to_cort, 'symbol', '');
hold on;
scatter(ones(1,10), human_wake_thal_to_cort, 100, 'filled', 'k');
scatter(ones(1,10)+1, human_anesthesia_thal_to_cort, 100, 'filled', 'r');
set(gca, 'XTickLabel', {'Awake', 'Propofol'}, 'FontSize', 15);
ylabel({'Cross-Frequency Thalamocortical'; 'Information Transfer'});
title({names{1}; thal_to_cort_titles{1}});
set(gca, 'Fontsize', 20);
for i = 1:10
    plot([1 2], [human_wake_thal_to_cort(i) human_anesthesia_thal_to_cort(i)], 'Color', [0, 0, 0, 0.3])
end
text(1.5, max(human_wake_thal_to_cort), p_string, 'HorizontalAlignment', 'center', 'FontSize', 30);


all_rat_swd_cort_to_thal = [rat_seizure_wake_cort_to_thal' rat_seizure_swd_cort_to_thal'];
p = signrank(rat_seizure_wake_cort_to_thal, rat_seizure_swd_cort_to_thal, 'Tail', 'right');
if p > 0.05
    p_string = p_strings{1};
elseif p < 0.05 && p >= 0.01
    p_string = p_strings{2};
elseif p < 0.01 && p >= 0.001
    p_string = p_strings{3};
else
    p_string = p_strings{4};
end
figure('Position', [44 0 778 505]);   
boxplot(all_rat_swd_cort_to_thal, 'symbol', '');
hold on;
scatter(ones(1,7), rat_seizure_wake_cort_to_thal, 100, 'filled', 'k');
scatter(ones(1,7)+1, rat_seizure_swd_cort_to_thal, 100, 'filled', 'g');
title({names{3}; cort_to_thal_titles{3}});
set(gca, 'XTickLabel', {'Awake', 'Spike-and-Wave Seizure'}, 'FontSize', 15);
ylabel({'Cross-Frequency Corticothalamic'; 'Information Transfer'});
set(gca, 'Fontsize', 20);
for i = 1:7
    plot([1 2], [rat_seizure_wake_cort_to_thal(i) rat_seizure_swd_cort_to_thal(i)], 'Color', [0, 0, 0, 0.3])
end
text(1.5, max(rat_seizure_wake_cort_to_thal), p_string, 'HorizontalAlignment', 'center', 'FontSize', 30);


all_rat_swd_thal_to_cort = [rat_seizure_wake_thal_to_cort' rat_seizure_swd_thal_to_cort'];
p = signrank(rat_seizure_wake_thal_to_cort, rat_seizure_swd_thal_to_cort, 'Tail', 'right');
if p > 0.05
    p_string = p_strings{1};
elseif p < 0.05 && p >= 0.01
    p_string = p_strings{2};
elseif p < 0.01 && p >= 0.001
    p_string = p_strings{3};
else
    p_string = p_strings{4};
end
figure('Position', [44 0 778 505]);   
boxplot(all_rat_swd_thal_to_cort, 'symbol', '');
hold on;
scatter(ones(1,7), rat_seizure_wake_thal_to_cort, 100, 'filled', 'k');
scatter(ones(1,7)+1, rat_seizure_swd_thal_to_cort, 100, 'filled', 'g');
set(gca, 'XTickLabel', {'Awake', 'Spike-and-Wave Seizure'}, 'FontSize', 15);
ylabel({'Cross-Frequency Thalamocortical'; 'Information Transfer'});
title({names{3}; thal_to_cort_titles{3}});
set(gca, 'Fontsize', 20);
for i = 1:7
    plot([1 2], [rat_seizure_wake_thal_to_cort(i) rat_seizure_swd_thal_to_cort(i)], 'Color', [0, 0, 0, 0.3])
end
text(1.5, max(rat_seizure_wake_thal_to_cort), p_string, 'HorizontalAlignment', 'center', 'FontSize', 30);


all_rat_dmt_cort_to_thal = [mouse_dmt_wake_cort_to_thal' mouse_dmt_dmt_cort_to_thal'];
p = signrank(mouse_dmt_wake_cort_to_thal, mouse_dmt_dmt_cort_to_thal, 'Tail', 'left');
if p > 0.05
    p_string = p_strings{1};
elseif p < 0.05 && p >= 0.01
    p_string = p_strings{2};
elseif p < 0.01 && p >= 0.001
    p_string = p_strings{3};
else
    p_string = p_strings{4};
end
figure('Position', [44 0 778 505]);   
boxplot(all_rat_dmt_cort_to_thal, 'symbol', '');
hold on;
scatter(ones(1,5), mouse_dmt_wake_cort_to_thal, 100, 'filled', 'k');
scatter(ones(1,5)+1, mouse_dmt_dmt_cort_to_thal, 100, 'filled', 'm');
set(gca, 'XTickLabel', {'Awake', '5-MeO-DMT'}, 'FontSize', 15);
ylabel({'Cross-Frequency Corticothalamic'; 'Information Transfer'});
set(gca, 'Fontsize', 20);
title({names{4}; cort_to_thal_titles{4}});
for i = 1:5
    plot([1 2], [mouse_dmt_wake_cort_to_thal(i) mouse_dmt_dmt_cort_to_thal(i)], 'Color', [0, 0, 0, 0.3])
end
text(1.5, max(mouse_dmt_dmt_cort_to_thal), p_string, 'HorizontalAlignment', 'center', 'FontSize', 30);


all_rat_dmt_thal_to_cort = [mouse_dmt_wake_thal_to_cort' mouse_dmt_dmt_thal_to_cort'];
p = signrank(mouse_dmt_wake_thal_to_cort, mouse_dmt_dmt_thal_to_cort, 'Tail', 'left');
if p > 0.05
    p_string = p_strings{1};
elseif p < 0.05 && p >= 0.01
    p_string = p_strings{2};
elseif p < 0.01 && p >= 0.001
    p_string = p_strings{3};
else
    p_string = p_strings{4};
end
figure('Position', [44 0 778 505]);   
boxplot(all_rat_dmt_thal_to_cort, 'symbol', '');
hold on;
scatter(ones(1,5), mouse_dmt_wake_thal_to_cort, 100, 'filled', 'k');
scatter(ones(1,5)+1, mouse_dmt_dmt_thal_to_cort, 100, 'filled', 'm');
set(gca, 'XTickLabel', {'Saline', '5-MeO-DMT'}, 'FontSize', 15);
ylabel({'Cross-Frequency Thalamocortical'; 'Information Transfer'});
title({names{4}; thal_to_cort_titles{4}});
set(gca, 'Fontsize', 20);
for i = 1:5
    plot([1 2], [mouse_dmt_wake_thal_to_cort(i) mouse_dmt_dmt_thal_to_cort(i)], 'Color', [0, 0, 0, 0.3])
end
text(1.5, max(mouse_dmt_dmt_thal_to_cort), p_string, 'HorizontalAlignment', 'center', 'FontSize', 30);

